@@ -1,10 +1,9 @@
-/* fstype.c -- determine type of filesystems that files are on
+/* fstype.c -- determine type of file systems that files are on
    Copyright (C) 1990, 91, 92, 93, 94, 2000, 2004 Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* Written by David MacKenzie <djm@gnu.org>.
@@ -27,22 +24,20 @@
 
 #include <config.h>
 #include <errno.h>
-#include <assert.h>
 #include <stdbool.h>
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
+#include <sys/stat.h>
 
 /* The presence of unistd.h is assumed by gnulib these days, so we 
  * might as well assume it too. 
  */
 #include <unistd.h>
 
-#ifdef HAVE_SYS_MNTIO_H
-#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
-#endif
+#ifdef HAVE_SYS_MNTIO_H
 #include <sys/mntio.h>
 #endif
 #ifdef HAVE_SYS_MKDEV_H
@@ -82,7 +77,7 @@ extern int errno;
 # define N_(String) String
 #endif
 
-static char *filesystem_type_uncached PARAMS((const struct stat *statp, const char *path));
+static char *file_system_type_uncached PARAMS((const struct stat *statp, const char *path));
 
 
 /* Get MNTTYPE_IGNORE if it is available. */
@@ -149,13 +144,13 @@ in_afs (char *path)
 }
 #endif /* AFS */
 
-/* Nonzero if the current filesystem's type is known.  */
+/* Nonzero if the current file system's type is known.  */
 static int fstype_known = 0;
 
-/* Return a static string naming the type of filesystem that the file PATH,
+/* Return a static string naming the type of file system that the file PATH,
    described by STATP, is on.
    RELPATH is the file name relative to the current directory.
-   Return "unknown" if its filesystem type is unknown.  */
+   Return "unknown" if its file system type is unknown.  */
 
 char *
 filesystem_type (const struct stat *statp, const char *path)
@@ -170,7 +165,7 @@ filesystem_type (const struct stat *statp, const char *path)
       free (current_fstype);
     }
   current_dev = statp->st_dev;
-  current_fstype = filesystem_type_uncached (statp, path);
+  current_fstype = file_system_type_uncached (statp, path);
   return current_fstype;
 }
 
@@ -205,20 +200,20 @@ must_read_fs_list(bool need_fs_type)
        * use because gnulib has extracted all that stuff away. 
        * Hence we cannot issue a specific error message here.
        */
-      error(1, 0, "Cannot read mounted filesystem list");
+      error(1, 0, "Cannot read mounted file system list");
     }
   return entries;
 }
 
 
 
-/* Return a newly allocated string naming the type of filesystem that the
+/* Return a newly allocated string naming the type of file system that the
    file PATH, described by STATP, is on.
    RELPATH is the file name relative to the current directory.
-   Return "unknown" if its filesystem type is unknown.  */
+   Return "unknown" if its file system type is unknown.  */
 
 static char *
-filesystem_type_uncached (const struct stat *statp, const char *path)
+file_system_type_uncached (const struct stat *statp, const char *path)
 {
   struct mount_entry *entries, *entry;
   char *type;
@@ -251,8 +246,12 @@ filesystem_type_uncached (const struct stat *statp, const char *path)
 
   /* Don't cache unknown values. */
   fstype_known = (type != NULL);
-  
-  return type ? type : xstrdup(_("unknown"));
+  if (type)
+    return type;
+  else
+    return xstrdup(_("unknown"
+		     /* TRANSLATORS: this is essentially an abbreviation 
+			for "unknown file system type" */));
 }
 
 
