@@ -2,10 +2,10 @@
    Copyright (C) 1990, 91, 92, 93, 94, 2000, 
                  2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.*/
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 /* This file was written by James Youngman, based on find.c.
    
@@ -39,11 +38,8 @@
 #include <errno.h>
 #include <assert.h>
 
-#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
-#else
-#include <sys/file.h>
-#endif
+#include <sys/stat.h>
 
 #include <unistd.h>
 
@@ -81,7 +77,7 @@
 
 static void set_close_on_exec(int fd)
 {
-#if defined(F_GETFD) && defined(FD_CLOEXEC)
+#if defined F_GETFD && defined FD_CLOEXEC
   int flags;
   flags = fcntl(fd, F_GETFD);
   if (flags >= 0)
@@ -106,8 +102,8 @@ int get_current_dirfd(void)
 {
   if (ftsoptions & FTS_CWDFD)
     {
-      assert(curr_fd != -1);
-      assert( (AT_FDCWD == curr_fd) || (curr_fd >= 0) );
+      assert (curr_fd != -1);
+      assert ( (AT_FDCWD == curr_fd) || (curr_fd >= 0) );
       
       if (AT_FDCWD == curr_fd)
 	return starting_desc;
@@ -145,7 +141,7 @@ static void inside_dir(int dirfd)
 {
   if (ftsoptions & FTS_CWDFD)
     {
-      assert(dirfd == AT_FDCWD || dirfd >= 0);
+      assert (dirfd == AT_FDCWD || dirfd >= 0);
       
       state.cwd_dir_fd = dirfd;
       if (curr_fd < 0)
@@ -164,7 +160,7 @@ static void inside_dir(int dirfd)
 	      /* curr_fd is invalid, but dirfd is also invalid.
 	       * This should not have happened.
 	       */
-	      assert(curr_fd >= 0 || dirfd >= 0);
+	      assert (curr_fd >= 0 || dirfd >= 0);
 	    }
 	}
     }
@@ -268,7 +264,7 @@ partial_quotearg_n(int n, char *s, size_t len, enum quoting_style style)
 }
 
 
-/* We've detected a filesystem loop.   This is caused by one of 
+/* We've detected a file system loop.   This is caused by one of 
  * two things:
  *
  * 1. Option -L is in effect and we've hit a symbolic link that 
@@ -299,8 +295,8 @@ issue_loop_warning(FTSENT * ent)
        * to /a/b/c.
        */
       error(0, 0,
-	    _("Filesystem loop detected; "
-	      "%s is part of the same filesystem loop as %s."),
+	    _("File system loop detected; "
+	      "%1$s is part of the same file system loop as %2$s."),
 	    safely_quote_err_filename(0, ent->fts_path),
 	    partial_quotearg_n(1,
 			       ent->fts_cycle->fts_path,
@@ -475,8 +471,8 @@ consider_visiting(FTS *p, FTSENT *ent)
   if (ent->fts_info == FTS_NSOK
       || ent->fts_info == FTS_NS /* e.g. symlink loop */)
     {
-      assert(!state.have_stat);
-      assert(!state.have_type);
+      assert (!state.have_stat);
+      assert (!state.have_type);
       state.type = mode = 0;
     }
   else
@@ -611,7 +607,10 @@ find(char *arg)
   p = fts_open(arglist, ftsoptions, NULL);
   if (NULL == p)
     {
-      error (0, errno, _("cannot search %s"),
+      error (0, errno, _("cannot search %s"
+			 /* TRANSLATORS: the argument is either
+			    a file or a directory. */
+			 ),
 	     safely_quote_err_filename(0, arg));
     }
   else
@@ -668,9 +667,8 @@ main (int argc, char **argv)
   state.execdirs_outstanding = false;
   state.cwd_dir_fd = AT_FDCWD;
 
-  /* Set the option defaults before we do the the locale
-   * initialisation as check_nofollow() needs to be executed in the
-   * POSIX locale.
+  /* Set the option defaults before we do the locale initialisation as
+   * check_nofollow() needs to be executed in the POSIX locale.
    */
   set_option_defaults(&options);
   
@@ -704,7 +702,7 @@ main (int argc, char **argv)
    * To avoid bailing out when something gets automounted, it checks if 
    * the target directory appears to have had a directory mounted on it as
    * we chdir()ed.  The problem with this is that in order to notice that 
-   * a filesystem was mounted, we would need to lstat() all the mount points.
+   * a file system was mounted, we would need to lstat() all the mount points.
    * That strategy loses if our machine is a client of a dead NFS server.
    *
    * Hence if safely_chdir() and wd_sanity_check() can manage without needing 
