@@ -1,20 +1,18 @@
 /* buildcmd.[ch] -- build command lines from a stream of arguments
    Copyright (C) 2005 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
  * Written by James Youngman.
@@ -103,7 +101,7 @@ enum BC_INIT_STATUS
   {
     BC_INIT_OK = 0,
     BC_INIT_ENV_TOO_BIG,
-    BC_INIT_CANNOT_ACCOMODATE_HEADROOM,
+    BC_INIT_CANNOT_ACCOMODATE_HEADROOM
   };
 
 extern size_t bc_size_of_environment (void);
